@@ -1,8 +1,8 @@
 #!/bin/sh
-export PATH='/usr/obj/ports/hs-HDBC-postgresql-2.3.2.2/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
+export PATH='/usr/obj/hs-HDBC-postgresql-2.3.2.3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: HDBC-postgresql
-version: 2.3.2.2
-id: HDBC-postgresql-2.3.2.2-46b64058b12de1db5b4ae97530060a31
+version: 2.3.2.3
+id: HDBC-postgresql-2.3.2.3-8ea65586419d7255c47a3677519844d8
 
 license: BSD3
 copyright: Copyright (c) 2005-2011 John Goerzen
@@ -24,29 +24,29 @@ hidden-modules: Database.HDBC.PostgreSQL.Connection
                 Database.HDBC.PostgreSQL.PTypeConv
                 Database.HDBC.PostgreSQL.ErrorCodes
 trusted: False
-import-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.2
-library-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.2
+import-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.3
+library-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.3
               /usr/local/lib
-hs-libraries: HSHDBC-postgresql-2.3.2.2
+hs-libraries: HSHDBC-postgresql-2.3.2.3
 extra-libraries: pq crypto ssl
 extra-ghci-libraries:
 include-dirs: /usr/local/include/postgresql
 includes:
-depends: HDBC-2.4.0.0-3ae4d4df9f3738c553c3bbc8068067d1
-         base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
-         bytestring-0.10.4.0-c38ffa96fe2b16989b0dffe49eb81a0b
-         convertible-1.1.0.0-28989c2b8ff74cb2fd86deba0c48707c
-         mtl-2.1.3.1-37f47084eacfb82b92e11a8c90d0ba72
-         old-locale-1.0.0.6-5787526c2e79da8a846be3a88dc42a6d
-         old-time-1.1.0.2-4d6b62bf66ac20e6550b5bf9e9cfea48
-         parsec-3.1.5-c1d51f786b256997ac45d6a96ddda352
-         time-1.4.2-fc089836b34bdfee5ff8fc5b4f21945e
-         utf8-string-0.3.8-deb6f3b52f6d22ffddb7305b5e4f676f
+depends: HDBC-2.4.0.1-1038b5935908fdeb0ea441a0b454b89d
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         convertible-1.1.1.0-516cd51642bbe3890bf5e36a38685ba3
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         old-locale-1.0.0.6-50b0125c49f76af85dc7aa22975cdc34
+         old-time-1.1.0.2-e3f776e97c1a6ff1770b04943a7ef7c6
+         parsec-3.1.5-7f6674da593b27c3fdd904274a0dcd1e
+         time-1.4.2-311aa8e77a6af87dc3d662d572df62ec
+         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.2/html/HDBC-postgresql.haddock
-haddock-html: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.2/html
+haddock-interfaces: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.3/html/HDBC-postgresql.haddock
+haddock-html: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.3/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
